@@ -1,18 +1,14 @@
-/**
- * Compiler implementation of the
- * $(LINK2 http://www.dlang.org, D programming language).
- *
- * Copyright:   Copyright (C) 1999-2018 by The D Language Foundation, All Rights Reserved
- * Authors:     $(LINK2 http://www.digitalmars.com, Walter Bright)
- * License:     $(LINK2 http://www.boost.org/LICENSE_1_0.txt, Boost License 1.0)
+
+/* Compiler implementation of the D programming language
+ * Copyright (C) 1999-2020 by The D Language Foundation, All Rights Reserved
+ * written by Walter Bright
+ * http://www.digitalmars.com
+ * Distributed under the Boost Software License, Version 1.0.
+ * http://www.boost.org/LICENSE_1_0.txt
+ * https://github.com/dlang/dmd/blob/master/src/dmd/nspace.h
  */
 
-#ifndef DMD_NSPACE_H
-#define DMD_NSPACE_H
-
-#ifdef __DMC__
 #pragma once
-#endif /* __DMC__ */
 
 #include "dsymbol.h"
 
@@ -23,6 +19,7 @@
 class Nspace : public ScopeDsymbol
 {
   public:
+    Expression *identExp;
     Dsymbol *syntaxCopy(Dsymbol *s);
     void addMember(Scope *sc, ScopeDsymbol *sds);
     void setScope(Scope *sc);
@@ -35,5 +32,3 @@ class Nspace : public ScopeDsymbol
     Nspace *isNspace() { return this; }
     void accept(Visitor *v) { v->visit(this); }
 };
-
-#endif /* DMD_NSPACE_H */
