@@ -351,9 +351,10 @@ void parseCommandLine(Strings &sourceFiles) {
   global.params.objname = opts::fromPathString(objectFile);
   global.params.objdir = opts::fromPathString(objectDir);
 
-  global.params.docdir = opts::fromPathString(ddocDir).ptr;
-  global.params.docname = opts::fromPathString(ddocFile).ptr;
-  global.params.doDocComments |= global.params.docdir || global.params.docname;
+  global.params.docdir = opts::fromPathString(ddocDir);
+  global.params.docname = opts::fromPathString(ddocFile);
+  global.params.doDocComments |=
+      global.params.docdir.length || global.params.docname.length;
 
   global.params.jsonfilename = opts::fromPathString(jsonFile);
   if (global.params.jsonfilename.length) {
@@ -365,6 +366,11 @@ void parseCommandLine(Strings &sourceFiles) {
   global.params.doHdrGeneration |=
       global.params.hdrdir.length || global.params.hdrname.length;
 
+  global.params.cxxhdrdir = opts::fromPathString(cxxHdrDir);
+  global.params.cxxhdrname = opts::fromPathString(cxxHdrFile);
+  global.params.doCxxHdrGeneration |=
+      global.params.cxxhdrdir.length || global.params.cxxhdrname.length;
+
   global.params.mixinFile = opts::fromPathString(mixinFile).ptr;
 
   if (moduleDeps.getNumOccurrences() != 0) {
@@ -836,8 +842,11 @@ void registerPredefinedTargetVersions() {
   default:
     if (triple.getEnvironment() == llvm::Triple::Android) {
       VersionCondition::addPredefinedGlobalIdent("Android");
-    } else if (triple.getOSName() != "unknown") {
-      warning(Loc(), "unknown target OS: %s", triple.getOSName().str().c_str());
+    } else {
+      llvm::StringRef osName = triple.getOSName();
+      if (!osName.empty() && osName != "unknown" && osName != "none") {
+        warning(Loc(), "unknown target OS: %s", osName.str().c_str());
+      }
     }
     break;
   }
